from .context import Context as context

from . import types
from . import ops
from . import app
from . import utils
from . import context
from . import path
from . import props

data = None  # type:  bpy.types.BlendData
'''Access to Blenders internal data '''
